( cd usr/share/java ; rm -rf xalan.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/xalan.jar xalan.jar )
( cd usr/share/java ; rm -rf xsltc.jar )
( cd usr/share/java ; ln -sf /usr/share/ant/lib/xsltc.jar xsltc.jar )
